aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/acp/acp_extensions.php
diff options
context:
space:
mode:
authorjaviexin <javiexin@gmail.com>2017-02-19 22:01:02 +0100
committerjaviexin <javiexin@gmail.com>2017-02-19 22:01:02 +0100
commitcdca848018571f2725aed207ead751823970a014 (patch)
tree89bb3c2699c67b225ced003753138be62ed03865 /phpBB/includes/acp/acp_extensions.php
parentd6771d6a7f12067c64f83ca3e249c7fb4084cc90 (diff)
downloadforums-cdca848018571f2725aed207ead751823970a014.tar
forums-cdca848018571f2725aed207ead751823970a014.tar.gz
forums-cdca848018571f2725aed207ead751823970a014.tar.bz2
forums-cdca848018571f2725aed207ead751823970a014.tar.xz
forums-cdca848018571f2725aed207ead751823970a014.zip
[ticket/14849] Add core.acp_extensions_run_action
Rename event to core.acp_extensions_run_action_before PHPBB-14849
Diffstat (limited to 'phpBB/includes/acp/acp_extensions.php')
-rw-r--r--phpBB/includes/acp/acp_extensions.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/phpBB/includes/acp/acp_extensions.php b/phpBB/includes/acp/acp_extensions.php
index 2befe57399..52282fbe6b 100644
--- a/phpBB/includes/acp/acp_extensions.php
+++ b/phpBB/includes/acp/acp_extensions.php
@@ -71,19 +71,20 @@ class acp_extensions
/**
* Event to run a specific action on extension
*
* @event core.acp_extensions_run_action
* @var string action Action to run; if the event executes completely the action, should be set to 'none'
* @var string u_action Url we are at
* @var string ext_name Extension name from request
* @var int safe_time_limit Safe limit of execution time
* @var int start_time Start time
* @var string tpl_name Template file to load
* @since 3.1.11-RC1
+ * @changed 3.2.1-RC1 Renamed to core.acp_extensions_run_action_before, added tpl_name, added action 'none'
*/
$u_action = $this->u_action;
$tpl_name = '';
$vars = array('action', 'u_action', 'ext_name', 'safe_time_limit', 'start_time', 'tpl_name');
- extract($this->phpbb_dispatcher->trigger_event('core.acp_extensions_run_action', compact($vars)));
+ extract($this->phpbb_dispatcher->trigger_event('core.acp_extensions_run_action_before', compact($vars)));
// In case they have been updated by the event
$this->u_action = $u_action;
@@ -71,19 +71,20 @@ class acp_extensions
* Event to run a specific action on extension
*
- * @event core.acp_extensions_run_action
- * @var string action Action to run; if the event executes completely the action, should be set to 'none'
+ * @event core.acp_extensions_run_action_before
+ * @var string action Action to run; if the event completes execution of the action, should be set to 'none'
* @var string u_action Url we are at
* @var string ext_name Extension name from request